*===============================================================================
* Project: Bulgaria Poverty Program
* Description: Harmonize HBS data for statistical matching
* Data: HBS 2019 
* Written by: Britta Rude (Poverty and Equity GP, World Bank)
* Last update: January 2023

* Important remarks: We follow the ECAPOV harmonization for income and energy  
*===============================================================================


clear all





*==============================================================================*
* Upload non-harmonized data 
*==============================================================================*

*Import data 
import excel "$data\Raw\hh_basic_${year}_HBS_BG.xlsx", clear firstrow

gen hhid=HA04
codebook HA04

global weight HA10

global samplevars HA06 HA07


*Prepare matching variables (harmonization) - A) Household level variables 
********************************************************************************

*Region

tab HA08
encode HA08, gen(regioncode)
tab regioncode, nolab

gen region= 3 if regioncode<5
replace region = 4 if regioncode>4

tab region regioncode //check

*Urban
gen urban = 0
replace urban = 1 if HA09!="3"

tab urban HA09 //check

*Income category
codebook HH099

gen weight_rounded = round(${weight}, 1)
		
xtile incomecat = HH099 [w=weight_rounded], nq(20)
tab incomecat


global matchingvarshh region urban incomecat






*Prepare energy variables 
********************************************************************************

*Identify energ vars
global energyvars HE_04_5_1_0 HE_04_5_2_1 HE_04_5_2_2 HE_04_5_3_0 HE_04_5_4_1 HE_04_5_4_9 HE_04_5_5_0

foreach var in $energyvars{
	codebook `var'
	sum `var'
}

label var HE_04_5_1_0 "Electricity"
label var HE_04_5_2_1 "Natural gas and town gas"
label var HE_04_5_2_2 "Liquified hydrocarbons/butane/propane"
label var HE_04_5_3_0 "Liquid fuels"
label var HE_04_5_4_1 "Coal"
label var HE_04_5_4_9 "Other solid fuels"
label var HE_04_5_5_0 "Heat energy"

label var HE_04_5 "Energy expenditure"

sum HE_04_5 [w=${weight}] 


*Add consumption aggregate

merge 1:1 hhid using "$data\consumptionagg.dta" //all match 
*Matched                             2,952

global energyvar HE_04_5
global welfarevar HH099 //gall_household
global electricityspending HE_04_5_1_0



gen energyspendingshare = ${energyvar}/${welfarevar} //at the household, not p.c. level
sum energyspendingshare
sum energyspendingshare [iw=${weight}] 


*Histogram (Figure A.3.)
hist energyspendingshare if energyspendingshare<1, color(blue) lcolor(black) percent xtitle("Energy spending share") width(0.0148148148)

graph export "$figures\hist_energyspendingshare_hbs_2019.png", replace




*B) Energy Poverty
********************************************************************************

*b.1. share
sum energyspendingshare [aw=$weight], detail
gen medianshare = `r(p50)'
gen energythresholdshare = 2*medianshare

gen energypoorshare = (energyspendingshare>energythresholdshare)
sum energypoorshare [w=$weight]

*b.2. absolute 
sum ${energyvar} [aw=$weight], detail
gen medianspending = `r(p50)' 
gen energythreshold = 0.5*medianspending

gen energypoorabs = (${energyvar}<energythreshold)
tab energypoorabs
sum energypoorabs [w=$weight]


*b.3. 10-percent 
cap drop energypoor10
gen energypoor10 = (energyspendingshare>0.1)
tab energypoor10
sum energypoor10 [w=$weight]


global energypov energypoorshare energypoorabs energypoor10




*Add energy component spending share
********************************************************************************

cap drop electricityspendingshare
gen electricityspendingshare = ${electricityspending}/${welfarevar} //at the household, not p.c. level
sum electricityspendingshare
sum electricityspendingshare [iw=${weight}]


foreach var in $energyvars{
	gen `var'share = `var'/${welfarevar}
	sum `var'share
	codebook  `var'share
}

sum HE_04_5_1_0share

global shares HE_04_5_1_0share HE_04_5_2_1share HE_04_5_2_2share HE_04_5_3_0share HE_04_5_4_1share HE_04_5_4_9share HE_04_5_5_0share




*Create matching variables from individual data
********************************************************************************

*Household ID 
codebook hhid //1 ID per observation 

gen MA04 = hhid

cap drop _merge



***Individual level characteristics (this is a copy from the work done by the ECASTATs team)

global hhid MA04

preserve

use "$data\Raw\hm_basic_${year}_HBS_BG.dta", clear //all match
codebook MA04 //6,446 --> individual level

*Pid_orig
gen str5 pid_orig = substr(MA05,2,1) 
replace pid_orig = "10" if MA05 == "10"
replace pid_orig = "11" if MA05 == "11" 
destring pid_orig , replace 
tab pid_orig

*Female
destring MB02, replace 
gen female = (MB02==2)
tab female

*Age
tab MB03
gen age = MB03  
replace age = "0"  if age == "Z0"
replace age = "1"  if age == "Z1"
replace age = "2"  if age == "Z2"
replace age = "3"  if age == "Z3"
replace age = "4"  if age == "Z4"
replace age = "5"  if age == "Z5"
replace age = "6"  if age == "Z6"
replace age = "7"  if age == "Z7"
replace age = "8"  if age == "Z8"
replace age = "9"  if age == "Z9"
destring age, replace 

*Agecatn
gen agecatn = .
forval i=0(5)95 {
	replace agecatn = 1+`i'/5 if inrange(age,`i',`i'+4)
}
replace agecatn = 20 if age>=100
replace agecatn = 21 if age==.
la var	agecatn						"Age by 5-year intervals, categorical (numeric)"
lab define agecatn 1 "00-04 years"  2 "05-09 years"  3 "10-14 years"  4 "15-19 years"   ///
	5 "20-24 years"  6 "25-29 years"  7 "30-34 years"  8 "35-39 years"  ///
	9 "40-44 years"  10 "45-49 years"  11 "50-54 years"  12 "55-59 years"  ///
	13 "60-64 years"  14 "65-69 years"  15 "70-74 years"  16 "75-79 years"  ///
	17 "80-84 years"  18 "85-89 years"  19 "90-94 years"  20 "95+ years"  21 "Not stated",modify   
lab val agecatn agecatn
tab agecatn

*agecat
decode agecatn, gen(agecat)

*Child
gen child = (agecatn<4)
tab child

*Elderly
gen elderly = (agecatn>13)
tab elderly

*Head
destring MB05, replace 
gen head = (MB05 == 1)  
tab head

*Female household head
gen femalehead = (female>0 & head==1)
tab femalehead

*Roma 
*Does not exist

*Unemployed
codebook ME01_A //Missing "": 0/6,446

gen unemployed=0
replace unemployed=1 if ME01_A=="Z2"
tab unemployed

sum age if unemployed==1 //goes from 17 to 76

*Self-employed
codebook ME12 //string

gen selfemployed = 0
replace selfemployed=1 if ME12=="1" | ME12=="2"
tab selfemployed ME12

*Primary sector
gen primarysector=0
replace primarysector=1 if ME04=="A"
tab primarysector ME04

*Part-time
cap drop parttime
gen parttime = 0
replace parttime = 2 if ME02=="1"
tab parttime ME02

*Max educ primary
gen primaryeduc = 0
replace primaryeduc = 1 if MC01=="Z0" | MC01=="Z1"
tab MC01 primaryeduc

*Secondary 
gen secondaryeduc = 0
replace secondaryeduc = 1 if MC01=="Z2" | MC01=="Z3" | MC01=="Z4"
tab MC01 secondaryeduc

*Tertiary
gen tertiaryeduc = 0
replace tertiaryeduc = 1 if MC01=="Z5" | MC01=="Z6" | MC01=="Z7" | MC01=="Z8"
tab MC01 tertiaryeduc

*Currently attending education
gen attendingeduc = 0
replace attendingeduc = 1 if MC02_A=="1"
tab attendingeduc MC02_A

*Foreign citizenship
gen foreigncitizen = 0
replace foreigncitizen = 1 if MB011!="1"
tab MB011 foreigncitizen

*Pensioner
gen pensioner = (ME01_A=="Z3")
tab pensioner

*Adultequ
gen child_ad=0
replace child_ad=0.5 if child==1

gen women_ad=0
replace women_ad = 0.8 if female==1
replace women_ad = 0 if child==1
tab women_ad 


gen men_ad = 0
replace men_ad = 1 if female==0
replace men_ad = 0 if child==1
tab men

cap drop adultequ
egen adultequ = total(child_ad+women_ad+men_ad), by($hhid)
sum adultequ

sort $hhid
list $hhid adultequ in 1/100



*Collapse to household level
********************************************************************************

global hhcharacteristics child pensioner elderly femalehead unemployed 
global memberinfo female selfemployed primarysector parttime primaryeduc secondaryeduc tertiaryeduc attendingeduc foreigncitizen

collapse (max) $hhcharacteristics (sum) $memberinfo nchild=child npensioner=pensioner nunemployed=unemployed (count) members=pid_orig (first) adultequ, by($hhid) //weight is not included in individual file  

foreach var in $hhcharacteristics{
	tab `var'
}

tab members
tab adultequ

label var child "Household with children (<15)"
label var pensioner "Household with pensioner"
label var elderly "Household with elderly (>64)"
label var femalehead "Female-headed household"
label var unemployed "Household with unemployed"
label var members "No. of household members"
label var adultequ "Adult equivalent"

label var nchild "No of children"
label var npensioner "No of pensioners"
label var nunemployed "No of unemployed"
label var female "No of female"
label var selfemployed "No of self-employed"
label var primarysector "No in primary sector"
label var parttime "No of part-time employed"
label var primaryeduc "No with primary educ."
label var secondaryeduc "No with secondary educ."
label var tertiaryeduc "No with tertiary educ."
label var attendingeduc "No attending educ."
label var foreigncitizen "No of foreign citizens"

*Save
tempfile hhcharacteristics
save `hhcharacteristics'

restore 

*Merge
merge 1:1 MA04 using `hhcharacteristics'
drop _merge

*Show hh characteristics

label var region "Region"
label var urban "Urban"
label var incomecat "Income cat. (1-20)"

global memberinfo nchild  npensioner  nunemployed female selfemployed primarysector parttime primaryeduc secondaryeduc tertiaryeduc attendingeduc foreigncitizen

outreg2 [aw=$weight] using "$tables/Summary_householdcharact.doc", sum(log) word replace keep($hhcharacteristics $memberinfo $matchingvarshh members adultequ) label //this Table is to check that all the variables are correct - it does not show up in the paper


*Show energy variables 

label var energyspendingshare "Energy spending share"

label var energypoorabs "Energy poverty incidence rate (absolute)"
label var energypoorshare "Energy poverty incidence rate (share)"
label var energypoor10 "Energy poverty (> 10 percent)"

label var HE_04_5_1_0share "Electricity (share)"
label var HE_04_5_2_1share "Natural gas and town gas (share)"
label var HE_04_5_2_2share "Liquified hydrocarbons/butane/propane (share)"
label var HE_04_5_3_0share "Liquid fuels (share)"
label var HE_04_5_4_1share "Coal (share)"
label var HE_04_5_4_9share "Other solid fuels (share)"
label var HE_04_5_5_0share "Heat energy (share)"

outreg2 [aw=$weight] using "$tables/Summary_energyvars.doc", sum(log) word replace keep($energypov energyspendingshare $shares) label //this is Table 1 in the paper




*Histogram of equivalized HH income
********************************************************************************

sum HH099
sum adultequ

gen income_equ = HH099/adultequ

label var income_equ "Equivalized household income"

hist income_equ [w=weight_round],  color(blue) lcolor(black)
graph export "$figures\hist_income_equivalized_hbs.png", replace //this is Figure A.1. in the paper

sum income_equ [w=$weight], d





*Income Quintiles
********************************************************************************
			
global incomevar income_equ		
		
xtile inc_pc_q = $incomevar [w=$weight], nq(5)

tab inc_pc_q
tab inc_pc_q [iw=$weight]

sum $incomevar if inc_pc_q==1
sum $incomevar if inc_pc_q==5


*Energy Spending by income quintiles (Figure 1)
********************************************************************************

bysort inc_pc_q: sum energyspendingshare [w=$weight] 

preserve

collapse (mean) energyspendingshare energypoor10 [w=$weight], by(inc_pc_q)

label var energyspendingshare "Energy spending share (observed)"
label var energypoor10 "Energy poverty (> 10 percent)"


// save to MS Excel
export excel using "$tables\Energyspendinshare_quintiles.xlsx", sheet("hbs_observed", modify) firstrow(varl) keepcellfmt

restore


*Save harmonized data for matching
********************************************************************************

keep $energypov energyspendingshare $shares $weight $hhcharacteristics $memberinfo $matchingvarshh members adultequ $hhid $samplevars

save "$data\Matching\HBS${year}_harmonized.dta", replace



