*===============================================================================
* Project: Bulgaria Poverty Program
* Description: Harmonize EU-SILC data for statistical matching
* Data: EU-SILC 2020 
* Written by: Britta Rude (Poverty and Equity GP, World Bank)
* Last update: January 2023

* Important remarks: We follow the ECAPOV harmonization for income and energy  
*===============================================================================




********************************************************************************
*EU-SILC
********************************************************************************

use "$data\SILC_2017_2020.dta", clear

tab ctry_n

tab year country

keep if code=="BGR"
keep if year==2020

tab year country

gen hhid = hhid_n //same name as in HBS

global hhid hhid

global samplevars db060 db062



*Weigh
global weight rb050
gen weight_round = round(${weight}, 1)

codebook weight_round


*Prepare matching variables (harmonization) 
********************************************************************************


*region
tab db040
gen region=3 if db040=="BG3" 
replace region=4 if db040=="BG4"
tab region db040 //check

*Urban
tab db100
gen urban=1
replace urban=0 if db100==3
tab urban db100

*Income cat
gen income = hx090*hx050
		
xtile incomecat = income [w=weight_round], nq(20)
tab incomecat


*Histogram of equivalized HH income
********************************************************************************

hist hx090 [w=weight_round],  color(blue) lcolor(black)
graph export "$figures\hist_income_equivalized_eusilc.png", replace //this is figure A.1. in the paper

sum hx090 [w=$weight], d




* Female headed (methodology adapted from previous Pov GP do-files)

* 2.Household id
egen hhid_year_psu = group(hhid_n year_n db062)
codebook hhid_year_psu
duplicates report hhid_year_psu

* 21.Household head (=1 if head, =0 otherwise)
set seed 696943
gen  rand = runiform()
sort hhid_year_psu year rand 
by   hhid_year_psu year: g i=_n
drop rand

cap drop hhead
gen hhead=(i==1)
drop i	
tab hhead	


*Female
gen female=(pb150==2)
tab female

*Female headed
gen femalehead = (female>0 & hhead==1)
tab femalehead

cap drop femaleheaded
bys hhid_year_psu: egen femaleheaded=max(femalehead)

*Members
gen members=hx040

*Adultequ
gen adultequ=hx050

*Age
gen age=rx020 /*age at the end of the income reference period*/
replace age=rx010 if age==.
assert age!=.

*Agecat
gen agecatn = .
forval i=0(5)95 {
	replace agecatn = 1+`i'/5 if inrange(age,`i',`i'+4)
}
replace agecatn = 20 if age>=100
replace agecatn = 21 if age==.
la var	agecatn						"Age by 5-year intervals, categorical (numeric)"
lab define agecatn 1 "00-04 years"  2 "05-09 years"  3 "10-14 years"  4 "15-19 years"   ///
	5 "20-24 years"  6 "25-29 years"  7 "30-34 years"  8 "35-39 years"  ///
	9 "40-44 years"  10 "45-49 years"  11 "50-54 years"  12 "55-59 years"  ///
	13 "60-64 years"  14 "65-69 years"  15 "70-74 years"  16 "75-79 years"  ///
	17 "80-84 years"  18 "85-89 years"  19 "90-94 years"  20 "95+ years"  21 "Not stated",modify   
lab val agecatn agecatn
tab agecatn

*Agecat
decode agecatn, gen(agecat)

tab age if agecatn==1 //check

*Single elderly household
gen elderly=(age>64)
gen single_elderly=0
replace single_elderly=1 if elderly==1 & members==1
tab single_elderly


*Child
gen child=(age<15)


*HH with +5 members
gen hh_5members = 0
replace hh_5members=1 if members>4
tab hh_5members

*Pensioner
gen pensioner = (py100g>0)
tab pensioner, m 
replace pensioner = 0 if missing(py100g)

*Unemployed
gen unemployed = (pl031==5)

*Self-employed
gen selfemployed = (pl031==3 | pl031==4)

*Primary sector
gen primarysector = (pl111=="a")

*Part-time
gen parttime = (pl031==2 | pl031==4)

*Max educ primary
gen primaryeduc = (pe040<=100)

*Secondary 
gen secondaryeduc = (inrange(pe040, 200, 354))

*Tertiary
gen tertiaryeduc = (pe040>354)

*Currently attending education
gen attendingeduc = (pe010==1)

*Foreign citizenship
gen foreigncitizen = (pb220a!="LOC")
replace foreigncitizen=0 if missing(pb220a)
tab foreigncitizen


global hhcharacteristics child pensioner elderly femalehead unemployed urban region incomecat //roma (does not xist)
global memberinfo female selfemployed primarysector parttime primaryeduc secondaryeduc tertiaryeduc attendingeduc foreigncitizen

global weight db090

collapse (max) $hhcharacteristics (sum) $memberinfo nchild=child npensioner=pensioner nunemployed=unemployed (first) members adultequ ${weight} ${samplevars}, by($hhid) //weight is not included in individual file

label var child "Household with children (<15)"
label var pensioner "Household with pensioner"
label var elderly "Household with elderly (>64)"
label var femalehead "Female-headed household"
label var unemployed "Household with unemployed"
label var members "No. of household members"
label var adultequ "Adult equivalent"

label var nchild "No of children"
label var npensioner "No of pensioners"
label var nunemployed "No of unemployed"
label var female "No of female"
label var selfemployed "No of self-employed"
label var primarysector "No in primary sector"
label var parttime "No of part-time employed"
label var primaryeduc "No with primary educ."
label var secondaryeduc "No with secondary educ."
label var tertiaryeduc "No with tertiary educ."
label var attendingeduc "No attending educ."
label var foreigncitizen "No of foreign citizens"

label var region "Region"
label var urban "Urban"
label var incomecat "Income cat. (1-20)"  

global memberinfo nchild npensioner nunemployed female selfemployed primarysector parttime primaryeduc secondaryeduc tertiaryeduc attendingeduc foreigncitizen

outreg2 [aw=$weight] using "$tables/Summary_householdcharact_eusilc.doc", sum(log) word replace keep($hhcharacteristics $memberinfo members adultequ) label //this table is for internal purposes to check that the variable are correct - it is not included in the paper.





*Save harmonized for matching
********************************************************************************

keep $weight $hhcharacteristics $memberinfo members adultequ $hhid ${samplevars}

save "$data\Matching\EUSIL${year}_harmonized.dta", replace






