*===============================================================================
* Project: Bulgaria Poverty Program
* Description: Create final data for statistical matching, concatinating as in Ruben 
* Data: EU-SILC 2020 and HBS 2019 - both harmonized previously to each other 
* Written by: Britta Rude (Poverty and Equity GP, World Bank)
* Last update: February 2023

* Important remarks: We follow the ECAPOV harmonization for income and energy  
*===============================================================================


********************************************************************************
*Upload data (harmonized)
********************************************************************************

use "$data\Matching\EUSILC2019_harmonized.dta", clear

codebook hhid //Missing .: 0/7,313


*Concat
********************************************************************************

append using "$data\Matching\HBS2019_harmonized.dta"

codebook MA04 //Unique values: 2,952                     Missing "": 7,313/10,265


*Weight and Sample Design
********************************************************************************

tostring hhid, replace
codebook hhid if hhid=="."

replace hhid=MA04 if hhid=="."
codebook hhid

gen weight=db090
replace weight=HA10 if missing(weight)

gen psu1 = db060
replace psu1 = HA06 if missing(psu1)
codebook psu1

gen psu2 = db062
replace psu2 = HA07 if missing(psu2)
codebook psu2

codebook weight


*Matching vars
********************************************************************************

global lassovars child pensioner elderly femalehead unemployed urban region incomecat female selfemployed primarysector parttime primaryeduc secondaryeduc tertiaryeduc attendingeduc foreigncitizen nchild npensioner nunemployed members adultequ


********************************************************************************
*Compare variables of both datasets to each other  
********************************************************************************

*Summary table by missing
gen missing = (missing(energyspendingshare))
tab missing if missing(energyspendingshare)

tab missing

*Only two regions are included in the EU-SILC, so I can also only use these two in the matched one
gen region3=(region==3)
label var region3 "Northern and Eastern Bulgaria"

gen region4=(region==4)
label var region4 "South-West and South-Central Bulgaria"


preserve

*Make sure that these are aligned between both datasets
global lassovars child pensioner elderly femalehead unemployed urban incomecat female selfemployed primarysector parttime primaryeduc secondaryeduc tertiaryeduc attendingeduc foreigncitizen nchild npensioner nunemployed members adultequ region3 region4

bysort missing: outreg2 [iw=weight] using "$tables\summary_missing.doc", replace sum(log) keep($lassovars) eqkeep(N mean sd) label

restore





*T-test

foreach var in $lassovars{
	ttest `var', by(missing)
}

eststo nonmissing: estpost summarize $lassovars if missing==0 [w=weight]
eststo missing: estpost summarize $lassovars if missing==1 [w=weight]
eststo groupdiff: estpost ttest ${lassovars}, by(missing)

***Generate Table 3 in the paper: 
esttab nonmissing missing groupdiff using "$tables/summary_missing_ttest.rtf", replace ///
cell("mean(pattern(1 1 0) fmt(2)) p(pattern(0 0 1) fmt(2))") ///
nogaps compress mtitle("Non-missing" "Missing" "T-test") label tex ///
title("Baseline characteristics and balance test of matching variables") addnote("Source: HBS (2019) and EU-SILC (2020).")




*Find potential auxiliary variables
********************************************************************************

*Correlation Table

preserve

keep if missing==0

corr energyspendingshare $lassovars

estpost corr energyspendingshare $lassovars [iw=HA10]
eststo correlation

esttab correlation using "$tables/correlationtable.rtf", replace label unstack not b(3) //this is Table A.3.

restore



*Lasso
********************************************************************************

lasso linear energyspendingshare $lassovars [iw=weight], folds(10)

lassocoef


global matchingvars pensioner elderly femalehead unemployed urban incomecat secondaryeduc






********************************************************************************
*Compare distribution of matching vars
********************************************************************************

*Unweighted --> these are not used in the paper, just for additional internal checks
foreach var in $matchingvars{
	   twoway (hist `var' if missing==0, color(blue%50) lcolor(black)) ///
	   (hist `var' if missing==1, color(red%50) lcolor(black)),    ///
	   legend(order (1 "HBS" 2 "EU-SILC")) title("Distribution `: var label `var''")
	graph export "$figures\kdensity_hbs_eusilc_`var'.png", replace

}

*Weighted --> these are the graphs in Appendix A.3.

gen rounded_weight = round(weight, 1)

foreach var in $matchingvars{
	   twoway (hist `var' [fw=rounded_weight] if missing==0, color(blue%50) lcolor(black)) ///
	   (hist `var' [fw=rounded_weight] if missing==1, color(red%50) lcolor(black)),    ///
	   legend(order (1 "HBS" 2 "EU-SILC")) title("Distribution `: var label `var''")
	graph export "$figures\kdensity_hbs_eusilc_`var'_weighted.png", replace

}


********************************************************************************
*Save final dataset
********************************************************************************

keep $matchingvars energyspending energypoor10 hhid weight psu1 psu2 members //keep members for validity check with non-matching var


save "$data\Matching\matchingdataset.dta", replace




