*===============================================================================
* Project: Bulgaria Poverty Program
* Description: Run several imputation models
* Data: EU-SILC 2020 and HBS 2019 - both harmonized previously to each other 
* Written by: Britta Rude (Poverty and Equity GP, World Bank)
* Last update: February 2023

* Important remarks: We follow the ECAPOV harmonization for income and energy  
*===============================================================================

********************************************************************************
*Upload data (harmonized)
********************************************************************************

use "$data\Matching\matchingdataset.dta", clear

*Set matching variables
global matchingvars pensioner elderly femalehead unemployed urban incomecat secondaryeduc

*Mi set data 
mi set mlong 

*Check if there are any missing
mi misstable summarize $matchingvars energyspending energypoor10 hhid weight psu1 psu2 //none are missing
 
hist energyspending
*hist energypoor10 

global samplevars i.psu1 //psu2


***The following generates all figures in Appendix 2 and additional figures in the main body of the paper***
 

********************************************************************************
*Imputation with linear regression model 
********************************************************************************

*With sample vars and weighted (Figure 2)

preserve

gen lnenergyspendingshare=ln(energyspendingshare)

label var lnenergyspendingshare "Energy spending share (log.)"

mi register imputed lnenergyspendingshare

set seed 298777
gen rand = runiform()
isid hhid rand
sort hhid rand
drop rand

mi impute regress lnenergyspendingshare ${matchingvars} ${samplevars} [w=weight], add(20) rseed(12345) replace

tab _mi_m

matrix imp=J(21,3,.)
matrix colnames imp="Number of imputation" "Mean" "Std. Dev."

forval i=0/20{
	
	local j = `i'+1

	mat imp[`j',1]=`i'
	
	replace energyspendingshare=exp(lnenergyspendingshare) if missing(energyspendingshare)
	
	sum energyspendingshare if _mi_m==`i'

	mat imp[`j',2]= round(r(mean),.001)
	mat imp[`j',3]= round(r(sd),.001)

}

matlist imp
mat2txt, matrix(imp) saving("${tables}\Imputation_energyspending_regress1.xls") replace

*Evaluate
sum energyspendingshare if _mi_m==0 
sum energyspendingshare if _mi_m>0 //Similar, but negative values 

hist energyspendingshare if _mi_m==0
hist energyspendingshare if _mi_m>0 //Similar, but negative values

mi xeq 0 1 20: sum energyspendingshare


twoway kdensity energyspendingshare if _mi_m==0 || ///
	   kdensity energyspendingshare if _mi_m>0,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_regress1.png", replace

twoway kdensity energyspendingshare if _mi_m==0 || ///
	   kdensity energyspendingshare if _mi_m>0 & energyspendingshare<1,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_regress1_restricted.png", replace

*Model output
mi estimate, dots post: regress lnenergyspendingshare ${matchingvars} ${samplevars} [w=weight]

return list
ereturn list 

outreg2 using "$tables\Models\reg_weighted_sample.doc", replace word label ///
addstat("Avg. RVI", e(rvi_avg_mi), "Avg. DF", e(df_avg_mi), "Max. FMI", e(fmi_max_mi), "F.stat", e(F_mi))

mi estimate, vartable

restore
 
 
 
*Without sample vars and weighted

preserve

gen lnenergyspendingshare=ln(energyspendingshare)

mi register imputed lnenergyspendingshare

mi impute regress lnenergyspendingshare ${matchingvars} [w=weight], add(20) rseed(12345) replace

tab _mi_m

matrix imp=J(21,3,.)
matrix colnames imp="Number of imputation" "Mean" "Std. Dev."

forval i=0/20{
	
	local j = `i'+1

	mat imp[`j',1]=`i'
	
	replace energyspendingshare=exp(lnenergyspendingshare) if missing(energyspendingshare)
	
	sum energyspendingshare if _mi_m==`i'

	mat imp[`j',2]= round(r(mean),.001)
	mat imp[`j',3]= round(r(sd),.001)

}

matlist imp
mat2txt, matrix(imp) saving("${tables}\Imputation_energyspending_regress2.xls") replace

*Evaluate
sum energyspendingshare if _mi_m==0 
sum energyspendingshare if _mi_m>0 //Similar, but negative values 

hist energyspendingshare if _mi_m==0
hist energyspendingshare if _mi_m>0 //Similar, but negative values

mi xeq 0 1 20: sum energyspendingshare


twoway kdensity energyspendingshare if _mi_m==0 || ///
	   kdensity energyspendingshare if _mi_m>0,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_regress2.png", replace

twoway kdensity energyspendingshare if _mi_m==0 || ///
	   kdensity energyspendingshare if _mi_m>0 & energyspendingshare<1,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_regress2_restricted.png", replace
  

restore
 
  
 
*Without sample vars and weight as control


*For income quintiles
preserve

use "${data}/SILC_2017_2020.dta", clear

tab ctry_n

tab year country

keep if code=="BGR"
keep if year==2020

tab year country 

*Save
tempfile eusilcbgr
save `eusilcbgr'

restore

preserve

gen lnenergyspendingshare=ln(energyspendingshare)

mi register imputed lnenergyspendingshare

mi impute regress lnenergyspendingshare ${matchingvars} weight, add(20) rseed(12345) replace

tab _mi_m

matrix imp=J(21,3,.)
matrix colnames imp="Number of imputation" "Mean" "Std. Dev."

forval i=0/20{
	
	local j = `i'+1

	mat imp[`j',1]=`i'
	
	replace energyspendingshare=exp(lnenergyspendingshare) if missing(energyspendingshare)
	
	sum energyspendingshare if _mi_m==`i'

	mat imp[`j',2]= round(r(mean),.001)
	mat imp[`j',3]= round(r(sd),.001)

}

matlist imp
mat2txt, matrix(imp) saving("${tables}\Imputation_energyspending_regress3.xls") replace

*Evaluate
sum energyspendingshare if _mi_m==0 
sum energyspendingshare if _mi_m>0 //Similar, but negative values 

hist energyspendingshare if _mi_m==0
hist energyspendingshare if _mi_m>0 //Similar, but negative values

mi xeq 0 1 20: sum energyspendingshare


twoway kdensity energyspendingshare if _mi_m==0 || ///
	   kdensity energyspendingshare if _mi_m>0,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_regress3.png", replace

twoway kdensity energyspendingshare if _mi_m==0 || ///
	   kdensity energyspendingshare if _mi_m>0 & energyspendingshare<1,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_regress3_restricted.png", replace


***By income quintiles
gen hhid_n=hhid
destring hhid_n, replace

merge m:m hhid_n using `eusilcbgr'


*Quintiles		
global incomevar hx090 //inc_pc		
		
xtile inc_pc_q = $incomevar [w=weight], nq(5)

tab inc_pc_q
tab inc_pc_q [iw=rb050]

sum inc_pc if inc_pc_q==1
sum inc_pc if inc_pc_q==5


*Energy spending share by income quintiles

collapse (mean) energyspendingshare [w=weight], by(inc_pc_q)

label var energyspendingshare "Energy spending share (imputed)"

// save to MS Excel
export excel using "$tables\Energyspendinshare_quintiles.xlsx", sheet("OLS_Spec3", modify) firstrow(varl) 


  

restore
  
 

 
 
********************************************************************************
*Imputation with predictive mean matching 
********************************************************************************

*With sample vars and weighted

preserve

mi register imputed energyspendingshare

mi impute pmm energyspendingshare ${matchingvars} ${samplevars} [iw=weight], knn(10) add(20) rseed(12345) noisily //this runs regress on observed data

tab _mi_m

matrix imp=J(21,3,.)
matrix colnames imp="Number of imputation" "Mean" "Std. Dev."

forval i=0/20{
	
	local j = `i'+1

	mat imp[`j',1]=`i'
	sum energyspendingshare if _mi_m==`i'

	mat imp[`j',2]= round(r(mean),.001)
	mat imp[`j',3]= round(r(sd),.001)

}

matlist imp
mat2txt, matrix(imp) saving("${tables}\Imputation_energyspending_pmm1.xls") replace

*Evaluate (without weights)
sum energyspendingshare if _mi_m==0 
sum energyspendingshare if _mi_m>0 //Similar, but negative values 

hist energyspendingshare if _mi_m==0,  color(blue) lcolor(black)
hist energyspendingshare if _mi_m>0,  color(blue) lcolor(black) //Similar, but negative values

twoway kdensity energyspendingshare if _mi_m==0 || ///
	   kdensity energyspendingshare if _mi_m>0,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_pmm1.png", replace

*By groups - female
twoway kdensity energyspendingshare if _mi_m==0 & female==1 || ///
	   kdensity energyspendingshare if _mi_m>0 & female==1,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_pmm1_female.png", replace

*By groups - male
twoway kdensity energyspendingshare if _mi_m==0 & female==0 || ///
	   kdensity energyspendingshare if _mi_m>0 & female==0,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_pmm1_male.png", replace

*By groups - lower income groups
twoway kdensity energyspendingshare if _mi_m==0 & incomecat<6 || ///
	   kdensity energyspendingshare if _mi_m>0 & incomecat<6,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_pmm1_lowincome.png", replace

*By groups - lower income groups
twoway kdensity energyspendingshare if _mi_m==0 & incomecat>5 || ///
	   kdensity energyspendingshare if _mi_m>0 & incomecat>5,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_pmm1_highincome.png", replace

*Evaluate (with weights)
sum energyspendingshare [w=weight] if _mi_m==0 
sum energyspendingshare [w=weight] if _mi_m>0 //Similar, but negative values 

gen weight_rounded = round(weight, 1)
hist energyspendingshare [w=weight_rounded] if _mi_m==0,  color(blue) lcolor(black)
hist energyspendingshare [w=weight_rounded] if _mi_m>0,  color(blue) lcolor(black) //Similar, but negative values

twoway kdensity energyspendingshare [w=weight] if _mi_m==0 || ///
	   kdensity energyspendingshare [w=weight] if _mi_m>0,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_pmm1_weighted.png", replace

*By groups - female
twoway kdensity energyspendingshare [w=weight] if _mi_m==0 & female==1 || ///
	   kdensity energyspendingshare [w=weight] if _mi_m>0 & female==1,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_pmm1_female.png", replace

*By groups - lower income groups
twoway kdensity energyspendingshare [w=weight] if _mi_m==0 & incomecat<6 || ///
	   kdensity energyspendingshare [w=weight] if _mi_m>0 & incomecat<6,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_pmm1_lowincome.png", replace

restore
 
 
 
 
*Without sample vars and weighted (Figure 3; Figure 5 to 8)

*For income quintiles
preserve

use "${data}/SILC_2017_2020.dta", clear

tab ctry_n

tab year country

keep if code=="BGR"
keep if year==2020

tab year country 

*Save
tempfile eusilcbgr
save `eusilcbgr'

restore

preserve

mi register imputed energyspendingshare

mi impute pmm energyspendingshare ${matchingvars} [iw=weight], knn(10) add(20) rseed(12345)

tab _mi_m

matrix imp=J(21,3,.)
matrix colnames imp="Number of imputation" "Mean" "Std. Dev."

forval i=0/20{
	
	local j = `i'+1

	mat imp[`j',1]=`i'
	sum energyspendingshare if _mi_m==`i'

	mat imp[`j',2]= round(r(mean),.001)
	mat imp[`j',3]= round(r(sd),.001)

}

matlist imp
mat2txt, matrix(imp) saving("${tables}\Imputation_energyspending_pmm2.xls") replace

*Evaluate (without weights)
sum energyspendingshare if _mi_m==0 
sum energyspendingshare if _mi_m>0 //Similar, but negative values 

hist energyspendingshare if _mi_m==0,  color(blue) lcolor(black)
hist energyspendingshare if _mi_m>0,  color(blue) lcolor(black) //Similar, but negative values

twoway kdensity energyspendingshare if _mi_m==0 || ///
	   kdensity energyspendingshare if _mi_m>0,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_pmm2.png", replace

*By groups - female
twoway kdensity energyspendingshare if _mi_m==0 & female==1 || ///
	   kdensity energyspendingshare if _mi_m>0 & female==1,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_pmm2_female.png", replace

*By groups - male
twoway kdensity energyspendingshare if _mi_m==0 & female==0 || ///
	   kdensity energyspendingshare if _mi_m>0 & female==0,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_pmm2_male.png", replace

*By groups - lower income groups
twoway kdensity energyspendingshare if _mi_m==0 & incomecat<6 || ///
	   kdensity energyspendingshare if _mi_m>0 & incomecat<6,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_pmm2_lowincome.png", replace

*By groups - lower income groups
twoway kdensity energyspendingshare if _mi_m==0 & incomecat>5 || ///
	   kdensity energyspendingshare if _mi_m>0 & incomecat>5,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_pmm2_highincome.png", replace

*Evaluate (with weights)
sum energyspendingshare [w=weight] if _mi_m==0 
sum energyspendingshare [w=weight] if _mi_m>0 //Similar, but negative values 

gen weight_rounded = round(weight, 1)
hist energyspendingshare [w=weight_rounded] if _mi_m==0,  color(blue) lcolor(black)
hist energyspendingshare [w=weight_rounded] if _mi_m>0,  color(blue) lcolor(black) //Similar, but negative values

twoway kdensity energyspendingshare [w=weight] if _mi_m==0 || ///
	   kdensity energyspendingshare [w=weight] if _mi_m>0,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_pmm2_weighted.png", replace

*By groups - female
twoway kdensity energyspendingshare [w=weight] if _mi_m==0 & female==1 || ///
	   kdensity energyspendingshare [w=weight] if _mi_m>0 & female==1,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_pmm2_female_weighted.png", replace

*By groups - lower income groups
twoway kdensity energyspendingshare [w=weight] if _mi_m==0 & incomecat<6 || ///
	   kdensity energyspendingshare [w=weight] if _mi_m>0 & incomecat<6,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_pmm2_lowincome_weighted.png", replace


***By income quintiles
gen hhid_n=hhid
destring hhid_n, replace

merge m:m hhid_n using `eusilcbgr'


*Quintiles		
global incomevar hx090 //inc_pc		
		
xtile inc_pc_q = $incomevar [w=weight], nq(5)

tab inc_pc_q
tab inc_pc_q [iw=rb050]

sum inc_pc if inc_pc_q==1
sum inc_pc if inc_pc_q==5


*Energy spending share by income quintiles

collapse (mean) energyspendingshare [w=weight], by(inc_pc_q)

label var energyspendingshare "Energy spending share (imputed)"

// save to MS Excel
export excel using "$tables\Energyspendinshare_quintiles.xlsx", sheet("PMM_Spec2", modify) firstrow(varl) 



restore
 
 


*Without sample vars and weight as control 

preserve

mi register imputed energyspendingshare

mi impute pmm energyspendingshare ${matchingvars} weight, knn(10) add(20) rseed(12345)

tab _mi_m

matrix imp=J(21,3,.)
matrix colnames imp="Number of imputation" "Mean" "Std. Dev."

forval i=0/20{
	
	local j = `i'+1

	mat imp[`j',1]=`i'
	sum energyspendingshare if _mi_m==`i'

	mat imp[`j',2]= round(r(mean),.001)
	mat imp[`j',3]= round(r(sd),.001)

}

matlist imp
mat2txt, matrix(imp) saving("${tables}\Imputation_energyspending_pmm3.xls") replace

*Evaluate (without weights)
sum energyspendingshare if _mi_m==0 
sum energyspendingshare if _mi_m>0 //Similar, but negative values 

hist energyspendingshare if _mi_m==0,  color(blue) lcolor(black)
hist energyspendingshare if _mi_m>0,  color(blue) lcolor(black) //Similar, but negative values

twoway kdensity energyspendingshare if _mi_m==0 || ///
	   kdensity energyspendingshare if _mi_m>0,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_pmm3.png", replace

*By groups - female
twoway kdensity energyspendingshare if _mi_m==0 & female==1 || ///
	   kdensity energyspendingshare if _mi_m>0 & female==1,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_pmm3_female.png", replace

*By groups - male
twoway kdensity energyspendingshare if _mi_m==0 & female==0 || ///
	   kdensity energyspendingshare if _mi_m>0 & female==0,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_pmm3_male.png", replace

*By groups - lower income groups
twoway kdensity energyspendingshare if _mi_m==0 & incomecat<6 || ///
	   kdensity energyspendingshare if _mi_m>0 & incomecat<6,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_pmm3_lowincome.png", replace

*By groups - lower income groups
twoway kdensity energyspendingshare if _mi_m==0 & incomecat>5 || ///
	   kdensity energyspendingshare if _mi_m>0 & incomecat>5,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_pmm3_highincome.png", replace

*Evaluate (with weights)
sum energyspendingshare [w=weight] if _mi_m==0 
sum energyspendingshare [w=weight] if _mi_m>0 //Similar, but negative values 

gen weight_rounded = round(weight, 1)
hist energyspendingshare [w=weight_rounded] if _mi_m==0,  color(blue) lcolor(black)
hist energyspendingshare [w=weight_rounded] if _mi_m>0,  color(blue) lcolor(black) //Similar, but negative values

twoway kdensity energyspendingshare [w=weight] if _mi_m==0 || ///
	   kdensity energyspendingshare [w=weight] if _mi_m>0,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_pmm3_weighted.png", replace

*By groups - female
twoway kdensity energyspendingshare [w=weight] if _mi_m==0 & female==1 || ///
	   kdensity energyspendingshare [w=weight] if _mi_m>0 & female==1,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_pmm3_female.png", replace

*By groups - lower income groups
twoway kdensity energyspendingshare [w=weight] if _mi_m==0 & incomecat<6 || ///
	   kdensity energyspendingshare [w=weight] if _mi_m>0 & incomecat<6,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_pmm3_lowincome.png", replace

restore




*Without sample vars and weighted (robustness: vary number of neighbors)

preserve

mi register imputed energyspendingshare

mi impute pmm energyspendingshare ${matchingvars} [iw=weight], knn(5) add(20) rseed(12345)

tab _mi_m

matrix imp=J(21,3,.)
matrix colnames imp="Number of imputation" "Mean" "Std. Dev."

forval i=0/20{
	
	local j = `i'+1

	mat imp[`j',1]=`i'
	sum energyspendingshare if _mi_m==`i'

	mat imp[`j',2]= round(r(mean),.001)
	mat imp[`j',3]= round(r(sd),.001)

}

matlist imp
mat2txt, matrix(imp) saving("${tables}\knn_robustness_Imputation_energyspending_pmm2.xls") replace

*Evaluate (without weights)
sum energyspendingshare if _mi_m==0 
sum energyspendingshare if _mi_m>0 //Similar, but negative values 

hist energyspendingshare if _mi_m==0,  color(blue) lcolor(black)
hist energyspendingshare if _mi_m>0,  color(blue) lcolor(black) //Similar, but negative values

twoway kdensity energyspendingshare if _mi_m==0 || ///
	   kdensity energyspendingshare if _mi_m>0,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\knn_robustness_kdensity_hbs_eusilc_pmm2.png", replace

*By groups - female
twoway kdensity energyspendingshare if _mi_m==0 & female==1 || ///
	   kdensity energyspendingshare if _mi_m>0 & female==1,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\knn_robustness_kdensity_hbs_eusilc_pmm2_female.png", replace

*By groups - male
twoway kdensity energyspendingshare if _mi_m==0 & female==0 || ///
	   kdensity energyspendingshare if _mi_m>0 & female==0,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\knn_robustness_kdensity_hbs_eusilc_pmm2_male.png", replace

*By groups - lower income groups
twoway kdensity energyspendingshare if _mi_m==0 & incomecat<6 || ///
	   kdensity energyspendingshare if _mi_m>0 & incomecat<6,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\knn_robustness_kdensity_hbs_eusilc_pmm2_lowincome.png", replace

*By groups - lower income groups
twoway kdensity energyspendingshare if _mi_m==0 & incomecat>5 || ///
	   kdensity energyspendingshare if _mi_m>0 & incomecat>5,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\knn_robustness_kdensity_hbs_eusilc_pmm2_highincome.png", replace

*Evaluate (with weights)
sum energyspendingshare [w=weight] if _mi_m==0 
sum energyspendingshare [w=weight] if _mi_m>0 //Similar, but negative values 

gen weight_rounded = round(weight, 1)
hist energyspendingshare [w=weight_rounded] if _mi_m==0,  color(blue) lcolor(black)
hist energyspendingshare [w=weight_rounded] if _mi_m>0,  color(blue) lcolor(black) //Similar, but negative values

twoway kdensity energyspendingshare [w=weight] if _mi_m==0 || ///
	   kdensity energyspendingshare [w=weight] if _mi_m>0,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\knn_robustness_kdensity_hbs_eusilc_pmm2_weighted.png", replace

*By groups - female
twoway kdensity energyspendingshare [w=weight] if _mi_m==0 & female==1 || ///
	   kdensity energyspendingshare [w=weight] if _mi_m>0 & female==1,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\knn_robustness_kdensity_hbs_eusilc_pmm2_female_weighted.png", replace

*By groups - lower income groups
twoway kdensity energyspendingshare [w=weight] if _mi_m==0 & incomecat<6 || ///
	   kdensity energyspendingshare [w=weight] if _mi_m>0 & incomecat<6,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\knn_robustness_kdensity_hbs_eusilc_pmm2_lowincome_weighted.png", replace

restore
 




  
********************************************************************************
*Imputation with truncated regression
********************************************************************************

*With sample vars and weighted

preserve

mi register imputed energyspendingshare

mi impute truncreg energyspendingshare ${matchingvars} ${samplevars} [w=weight], add(20) rseed(12345) replace ll(0) ul(1) force

tab _mi_m

matrix imp=J(21,3,.)
matrix colnames imp="Number of imputation" "Mean" "Std. Dev."

forval i=0/20{
	
	local j = `i'+1

	mat imp[`j',1]=`i'
	sum energyspendingshare if _mi_m==`i'

	mat imp[`j',2]= round(r(mean),.001)
	mat imp[`j',3]= round(r(sd),.001)

}

matlist imp
mat2txt, matrix(imp) saving("${tables}\Imputation_energyspending_truncated1.xls") replace

*Evaluate (without weights)
sum energyspendingshare if _mi_m==0 
sum energyspendingshare if _mi_m>0 //Similar, but negative values 

hist energyspendingshare if _mi_m==0,  color(blue) lcolor(black)
hist energyspendingshare if _mi_m>0,  color(blue) lcolor(black) //Similar, but negative values

twoway kdensity energyspendingshare if _mi_m==0 || ///
	   kdensity energyspendingshare if _mi_m>0,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_truncated1.png", replace

*By groups - female
twoway kdensity energyspendingshare if _mi_m==0 & female==1 || ///
	   kdensity energyspendingshare if _mi_m>0 & female==1,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_truncated1_female.png", replace

*By groups - male
twoway kdensity energyspendingshare if _mi_m==0 & female==0 || ///
	   kdensity energyspendingshare if _mi_m>0 & female==0,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_truncated1_male.png", replace

*By groups - lower income groups
twoway kdensity energyspendingshare if _mi_m==0 & incomecat<6 || ///
	   kdensity energyspendingshare if _mi_m>0 & incomecat<6,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_truncated1_lowincome.png", replace

*By groups - lower income groups
twoway kdensity energyspendingshare if _mi_m==0 & incomecat>5 || ///
	   kdensity energyspendingshare if _mi_m>0 & incomecat>5,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_truncated1_highincome.png", replace

*Evaluate (with weights)
sum energyspendingshare [w=weight] if _mi_m==0 
sum energyspendingshare [w=weight] if _mi_m>0 //Similar, but negative values 

gen weight_rounded = round(weight, 1)
hist energyspendingshare [w=weight_rounded] if _mi_m==0,  color(blue) lcolor(black)
hist energyspendingshare [w=weight_rounded] if _mi_m>0,  color(blue) lcolor(black) //Similar, but negative values

twoway kdensity energyspendingshare [w=weight] if _mi_m==0 || ///
	   kdensity energyspendingshare [w=weight] if _mi_m>0,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_truncated1_weighted.png", replace

*By groups - female
twoway kdensity energyspendingshare [w=weight] if _mi_m==0 & female==1 || ///
	   kdensity energyspendingshare [w=weight] if _mi_m>0 & female==1,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_pmm1_female.png", replace

*By groups - lower income groups
twoway kdensity energyspendingshare [w=weight] if _mi_m==0 & incomecat<6 || ///
	   kdensity energyspendingshare [w=weight] if _mi_m>0 & incomecat<6,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_truncated1_lowincome.png", replace

restore
 
 
 
 

*Without sample vars and weighted

preserve

mi register imputed energyspendingshare

mi impute truncreg energyspendingshare ${matchingvars} [w=weight], add(20) rseed(12345) replace ll(0) ul(1) force

tab _mi_m

matrix imp=J(21,3,.)
matrix colnames imp="Number of imputation" "Mean" "Std. Dev."

forval i=0/20{
	
	local j = `i'+1

	mat imp[`j',1]=`i'
	sum energyspendingshare if _mi_m==`i'

	mat imp[`j',2]= round(r(mean),.001)
	mat imp[`j',3]= round(r(sd),.001)

}

matlist imp
mat2txt, matrix(imp) saving("${tables}\Imputation_energyspending_truncated2.xls") replace

*Evaluate (without weights)
sum energyspendingshare if _mi_m==0 
sum energyspendingshare if _mi_m>0 //Similar, but negative values 

hist energyspendingshare if _mi_m==0,  color(blue) lcolor(black)
hist energyspendingshare if _mi_m>0,  color(blue) lcolor(black) //Similar, but negative values

twoway kdensity energyspendingshare if _mi_m==0 || ///
	   kdensity energyspendingshare if _mi_m>0,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_truncated2.png", replace

*By groups - female
twoway kdensity energyspendingshare if _mi_m==0 & female==1 || ///
	   kdensity energyspendingshare if _mi_m>0 & female==1,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_truncated2_female.png", replace

*By groups - male
twoway kdensity energyspendingshare if _mi_m==0 & female==0 || ///
	   kdensity energyspendingshare if _mi_m>0 & female==0,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_truncated2_male.png", replace

*By groups - lower income groups
twoway kdensity energyspendingshare if _mi_m==0 & incomecat<6 || ///
	   kdensity energyspendingshare if _mi_m>0 & incomecat<6,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_truncated2_lowincome.png", replace

*By groups - lower income groups
twoway kdensity energyspendingshare if _mi_m==0 & incomecat>5 || ///
	   kdensity energyspendingshare if _mi_m>0 & incomecat>5,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_truncated2_highincome.png", replace

*Evaluate (with weights)
sum energyspendingshare [w=weight] if _mi_m==0 
sum energyspendingshare [w=weight] if _mi_m>0 //Similar, but negative values 

gen weight_rounded = round(weight, 1)
hist energyspendingshare [w=weight_rounded] if _mi_m==0,  color(blue) lcolor(black)
hist energyspendingshare [w=weight_rounded] if _mi_m>0,  color(blue) lcolor(black) //Similar, but negative values

twoway kdensity energyspendingshare [w=weight] if _mi_m==0 || ///
	   kdensity energyspendingshare [w=weight] if _mi_m>0,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_truncated2_weighted.png", replace

*By groups - female
twoway kdensity energyspendingshare [w=weight] if _mi_m==0 & female==1 || ///
	   kdensity energyspendingshare [w=weight] if _mi_m>0 & female==1,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_pmm2_female.png", replace

*By groups - lower income groups
twoway kdensity energyspendingshare [w=weight] if _mi_m==0 & incomecat<6 || ///
	   kdensity energyspendingshare [w=weight] if _mi_m>0 & incomecat<6,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_truncated2_lowincome.png", replace

restore
  

  
  
  
*Without sample vars and weight as control (Figure 4)

*For income quintiles
preserve

use "${data}/SILC_2017_2020.dta", clear

tab ctry_n

tab year country

keep if code=="BGR"
keep if year==2020

tab year country 

*Save
tempfile eusilcbgr
save `eusilcbgr'

restore



preserve

mi register imputed energyspendingshare

mi impute truncreg energyspendingshare ${matchingvars} weight, add(20) rseed(12345) replace ll(0) ul(1) force

tab _mi_m

matrix imp=J(21,3,.)
matrix colnames imp="Number of imputation" "Mean" "Std. Dev."

forval i=0/20{
	
	local j = `i'+1

	mat imp[`j',1]=`i'
	sum energyspendingshare if _mi_m==`i'

	mat imp[`j',2]= round(r(mean),.001)
	mat imp[`j',3]= round(r(sd),.001)

}

matlist imp
mat2txt, matrix(imp) saving("${tables}\Imputation_energyspending_truncated3.xls") replace

*Evaluate (without weights)
sum energyspendingshare if _mi_m==0 
sum energyspendingshare if _mi_m>0 //Similar, but negative values 

hist energyspendingshare if _mi_m==0,  color(blue) lcolor(black)
hist energyspendingshare if _mi_m>0,  color(blue) lcolor(black) //Similar, but negative values

twoway kdensity energyspendingshare if _mi_m==0 || ///
	   kdensity energyspendingshare if _mi_m>0,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_truncated3.png", replace

*By groups - female
twoway kdensity energyspendingshare if _mi_m==0 & female==1 || ///
	   kdensity energyspendingshare if _mi_m>0 & female==1,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_truncated3_female.png", replace

*By groups - male
twoway kdensity energyspendingshare if _mi_m==0 & female==0 || ///
	   kdensity energyspendingshare if _mi_m>0 & female==0,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_truncated3_male.png", replace

*By groups - lower income groups
twoway kdensity energyspendingshare if _mi_m==0 & incomecat<6 || ///
	   kdensity energyspendingshare if _mi_m>0 & incomecat<6,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_truncated3_lowincome.png", replace

*By groups - lower income groups
twoway kdensity energyspendingshare if _mi_m==0 & incomecat>5 || ///
	   kdensity energyspendingshare if _mi_m>0 & incomecat>5,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_truncated3_highincome.png", replace

*Evaluate (with weights)
sum energyspendingshare [w=weight] if _mi_m==0 
sum energyspendingshare [w=weight] if _mi_m>0 //Similar, but negative values 

gen weight_rounded = round(weight, 1)
hist energyspendingshare [w=weight_rounded] if _mi_m==0,  color(blue) lcolor(black)
hist energyspendingshare [w=weight_rounded] if _mi_m>0,  color(blue) lcolor(black) //Similar, but negative values

twoway kdensity energyspendingshare [w=weight] if _mi_m==0 || ///
	   kdensity energyspendingshare [w=weight] if _mi_m>0,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_truncated3_weighted.png", replace

*By groups - female
twoway kdensity energyspendingshare [w=weight] if _mi_m==0 & female==1 || ///
	   kdensity energyspendingshare [w=weight] if _mi_m>0 & female==1,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_pmm3_female.png", replace

*By groups - lower income groups
twoway kdensity energyspendingshare [w=weight] if _mi_m==0 & incomecat<6 || ///
	   kdensity energyspendingshare [w=weight] if _mi_m>0 & incomecat<6,    ///
				legend(order (1 "True" 2 "Imputed")) xtitle("Energy spending share")
graph export "$figures\kdensity_hbs_eusilc_truncated3_lowincome.png", replace



***By income quintiles
gen hhid_n=hhid
destring hhid_n, replace

merge m:m hhid_n using `eusilcbgr'


*Quintiles		
global incomevar hx090 //inc_pc		
		
xtile inc_pc_q = $incomevar [w=weight], nq(5)

tab inc_pc_q
tab inc_pc_q [iw=rb050]

sum inc_pc if inc_pc_q==1
sum inc_pc if inc_pc_q==5


*Energy spending share by income quintiles

collapse (mean) energyspendingshare [w=weight], by(inc_pc_q)

label var energyspendingshare "Energy spending share (imputed)"

// save to MS Excel
export excel using "$tables\Energyspendinshare_quintiles.xlsx", sheet("Truncreg_Spec3", modify) firstrow(varl) 


restore
   
  
  
  
  