*===============================================================================
* Project: Bulgaria Poverty Program
* Description: Run several imputation models
* Data: EU-SILC 2020 and HBS 2019 - both harmonized previously to each other 
* Written by: Britta Rude (Poverty and Equity GP, World Bank)
* Last update: February 2023

* Important remarks: We follow the ECAPOV harmonization for income and energy  
*===============================================================================


********************************************************************************
*Upload data (harmonized)
********************************************************************************


use "$data\Matching\HBS${year}_harmonized.dta", clear


*Set matching variables
global matchingvars pensioner elderly femalehead unemployed urban incomecat secondaryeduc

*Set other globals
global samplevars i.HA06 //HA07

global weight HA10


*Outcome variable
gen lnenergyspendingshare=ln(energyspendingshare)

label var lnenergyspendingshare "Energy spending share (log.)"



********************************************************************************
*Regression - Appendix 6 - Table A.5.
********************************************************************************

*Reg 1
regress lnenergyspendingshare ${matchingvars} ${samplevars} [w=$weight]

outreg2 using "$tables\Models\Reg1.doc", replace dec(2) label drop($samplevars) addstat("MSE", e(rmse)) addtext("Sample FE", "Yes", "Weighted", "Yes") noomit 


*Reg 2
regress lnenergyspendingshare ${matchingvars} [w=$weight]

outreg2 using "$tables\Models\Reg1.doc", append dec(2) label drop($samplevars) addstat("MSE", e(rmse)) addtext("Sample FE", "No", "Weighted", "Yes") noomit


*Reg 3
regress lnenergyspendingshare ${matchingvars} $weight

outreg2 using "$tables\Models\Reg1.doc", append dec(2) label drop($samplevars) addstat("MSE", e(rmse)) addtext("Sample FE", "No", "Weighted", "No") noomit




********************************************************************************
*Trunreg - Table A.6.
********************************************************************************

cap drop energyspendingsharehat

*Trunreg 1
truncreg energyspendingshare ${matchingvars} ${samplevars} [w=$weight]

*Calculate R-squared
predict energyspendingsharehat
corr energyspendingshare energyspendingsharehat if e(sample)
local rsquared=round(r(rho)^2, 0.0001)
di `rsquared'
di r(rho)^2

outreg2 using "$tables\Models\TruncReg1.doc", replace dec(2) label drop($samplevars) addtext("Sample FE", "Yes", "Weighted", "Yes", "R-squared", `rsquared') noomit // addstat("MSE", e(rmse))

drop energyspendingsharehat


*Trunreg 2
truncreg energyspendingshare ${matchingvars} [w=$weight]

*Calculate R-squared
predict energyspendingsharehat
corr energyspendingshare energyspendingsharehat if e(sample)
local rsquared=round(r(rho)^2, 0.0001)
di `rsquared'
di r(rho)^2


outreg2 using "$tables\Models\TruncReg1.doc", append dec(2) label drop($samplevars) addtext("Sample FE", "No", "Weighted", "Yes", "R-squared", `rsquared') noomit // addstat("MSE", e(rmse))

drop energyspendingsharehat


*Trunreg 3
truncreg energyspendingshare ${matchingvars} $weight

*Calculate R-squared
predict energyspendingsharehat
corr energyspendingshare energyspendingsharehat if e(sample)
local rsquared=round(r(rho)^2, 0.0001)
di `rsquared'
di r(rho)^2

outreg2 using "$tables\Models\TruncReg1.doc", append dec(2) label drop($samplevars) addtext("Sample FE", "No", "Weighted", "No", "R-squared", `rsquared') noomit // addstat("MSE", e(rmse))

drop energyspendingsharehat




********************************************************************************
*PMM
********************************************************************************

*First, assume that 20 percent are missing

splitsample, generate(asmissing) values(0 1) split(0.8 0.2)  

tab asmissing

gen weight_rounded = round(${weight}, 1)



*PMM 1

***This is a semi-parametric estimation technique, so no model estimation output possible (only for the first regression calculating the distance)

teffects nnmatch (energyspendingshare ${matchingvars} $samplevars) (asmissing)[$weight_rounded], nneighbor(10) generate(stub1)

*Calculate MSE by hand 
predict energyspendingsharehat

gen mse = (energyspendingsharehat-energyspendingshare)^2

sum mse 

di sqrt(r(mean))

*Calculate R-squared
corr energyspendingshare energyspendingsharehat if e(sample)
di r(rho)^2






