*===============================================================================
* Project: Bulgaria Poverty Program
* Description: Run best performing imputation model
* Data: EU-SILC 2020 and HBS 2019 - both harmonized previously to each other 
* Written by: Britta Rude (Poverty and Equity GP, World Bank)
* Last update: February 2023

* Important remarks: We follow the ECAPOV harmonization for income and energy  
*===============================================================================



***Matching variables 
global matchingvars pensioner elderly femalehead unemployed urban incomecat secondaryeduc


********************************************************************************
*Upload data (harmonized)
********************************************************************************

use "$data\Matching\matchingdataset.dta", clear

*Mi set data 
mi set mlong


mi register imputed energyspendingshare

mi impute pmm energyspendingshare ${matchingvars} [iw=weight], knn(10) add(20) rseed(12345)

tab _mi_m

matrix imp=J(21,3,.)
matrix colnames imp="Number of imputation" "Mean" "Std. Dev."

forval i=1/20{
	
	local j = `i'+1

	mat imp[`j',1]=`i'
	sum energyspendingshare [iw=weight] if _mi_m==`i'

	mat imp[`j',2]= round(r(mean),.001)
	mat imp[`j',3]= round(r(sd),.001)
}

matlist imp
mat2txt, matrix(imp) saving("${tables}\Imputation_energyspending_pmm2.xls") replace //this is table A.4.





***Compare final imputation across matching vars (Figure in Appendix 4)

cap drop
gen missing= (_mi_m>0)
tab missing 
tab _mi_m missing

foreach var in $matchingvars{
		graph bar (mean) energyspendingshare [w=weight], over(missing) over(`var') asyvars ytitle("Mean") ///
		title("Mean energy expenditure share by `: var label `var''") bar(1, color(blue)) bar(2, color(red)) ///
		legend(order(1 "Observed" 2 "Imputed"))
		graph export "$figures\eshare_`var'_weighted.png", replace

}

***Figure in Appendix A.5.
foreach var in members{
		graph bar (mean) energyspendingshare [w=weight], over(missing) over(`var') asyvars ytitle("Mean") ///
		title("Mean energy expenditure share by `: var label `var''") bar(1, color(blue)) bar(2, color(red)) ///
		legend(order(1 "Observed" 2 "Imputed"))
		graph export "$figures\eshare_`var'_weighted.png", replace

}


***Generate final dataset

drop if _mi_m==0 //this is the original data

***Save final estimate


collapse (mean) $matchingvars energyspendingshare_imp=energyspendingshare (first) weight, by(hhid)

sum energyspendingshare_imp
sum energyspendingshare_imp [w=weight]
sum energyspendingshare_imp [iw=weight]


***Energy Poverty

*Energy Poverty

gen energypoor_imp = (energyspendingshare_imp>0.1)
sum energypoor_imp [w=weight] 


***Save 
save "$data\Matching\imputed_eusilc.dta", replace







********************************************************************************
*Overlap monetary and energy poverty 
********************************************************************************

use "$data\Matching\imputed_eusilc.dta", clear

gen hhid_n=hhid
destring hhid_n, replace

preserve

use "${data}/SILC_2017_2020.dta", clear

tab ctry_n

tab year country

keep if code=="BGR"
keep if year==2020

tab year country 

*Save
tempfile eusilcbgr
save `eusilcbgr'

restore

merge 1:m hhid_n using `eusilcbgr'




*Monetary Poverty
********************************************************************************

*Income per capita 
		gen inc_pc=(hx090*hx050)/hx040 //(equivalized disposable income*equivalized household size)/household members

		//Bring this to 2017-PPP-US$
		*Note: Nominal/Price Index (CPI) = Real 
		*ICP transforms to PPP-values
		gen double usd_ppp_pc = .	
		replace usd_ppp_pc = (inc_pc*hx010)/(icp2017*cpi2017) if missing(usd_ppp_pc) 
		*replace usd_ppp_pc = . if usd_ppp_pc<0 | missing(usd_ppp_pc)
		
		//Daily income per capita in 2017-PPP-US$
		replace usd_ppp_pc=usd_ppp_pc/365
		
		// Baseline poor-US$6.85
		apoverty usd_ppp_pc [aw=rb050], line(6.85) gen(poor_bl_685) 
		tab poor_bl_685 [iw=rb050], matcell(freq)


gen arop=hx080
sum arop
label var arop "At risk of poverty (60% median per AE household income)"
		
		
		
*Income Quintiles (Figure A.27 and Figure A.28)
********************************************************************************
		
global incomevar hx090 //inc_pc		
		
xtile inc_pc_q = $incomevar [w=rb050], nq(5)

tab inc_pc_q
tab inc_pc_q [iw=rb050]

sum inc_pc if inc_pc_q==1
sum inc_pc if inc_pc_q==5


*Energy spending share by income quintiles

preserve

collapse (mean) energyspendingshare_imp [w=rb050], by(inc_pc_q)

label var energyspendingshare "Energy spending share (imputed)"

// save to MS Excel
export excel using "$tables\Energyspendinshare_quintiles.xlsx", sheet("imputed", modify) firstrow(varl) 

restore




*Overlap energy poverty and monetary poverty
********************************************************************************

*ssc install venndiag //only do this once

global povertyindicator arop
*global povertyindicator poor_bl_685	
	
gen onlypoor = (${povertyindicator}==1 & energypoor_imp!=1)
tab onlypoor
label var onlypoor "Income poor but not energy poor"

gen onlyenergypoor = (${povertyindicator}!=1 & energypoor_imp==1)
tab onlyenergypoor
label var onlyenergypoor "Not income poor but energy poor"	

gen bothpoor = (${povertyindicator}==1 & energypoor_imp==1)
tab bothpoor
label var bothpoor "Both income and energy poor"	

gen nonpoor = (${povertyindicator}!=1 & energypoor_imp!=1)
tab nonpoor	
label var onlypoor "Neither income nor energy poor"


*Venndiagram (Figure A.4)

*venndiag ${povertyindicator} energypoor_imp [w=rb050] //does not with weights - needs manual preprocessing

preserve

collapse (sum) onlypoor onlyenergypoor bothpoor nonpoor [iw=rb050]

label var onlypoor "Income poor but not energy poor"
label var onlyenergypoor "Not income poor but energy poor"	
label var bothpoor "Both income and energy poor"	
label var nonpoor "Neither income nor energy poor"

xpose, clear

gen n=_n

rename v1 freq

gen poor = 1 if n==1
replace poor = 0 if n==2
replace poor = 1 if n==3
replace poor = 0 if n==4

gen energy = 0 if n==1
replace energy = 1 if n==2
replace energy = 1 if n==3
replace energy = 0 if n==4

expand freq

*Venn Diagramm
venndiag poor energy, saving("$figures\poverty_overlap_venn.png") //, show(lt)

restore




*Figure 10
preserve

collapse (sum) onlypoor onlyenergypoor bothpoor nonpoor [iw=rb050]

label var onlypoor "Income poor but not energy poor"
label var onlyenergypoor "Not income poor but energy poor"	
label var bothpoor "Both income and energy poor"	
label var nonpoor "Neither income nor energy poor"

graph bar onlypoor onlyenergypoor bothpoor nonpoor, stack percent legend(label(1 "Only income poor") label(2 "Only energy poor") label(3 "Both") label(4 "Neither")) ytitle("Percent")
graph export "$figures\poverty_overlap.png", replace //figure 10 


restore



********************************************************************************
********************************************************************************
*Save final
********************************************************************************
********************************************************************************

save "$data\Matching\imputed_eusilc_final.dta", replace



