*===============================================================================
* Project: Bulgaria Poverty Program
* Description: Harmonize HBS data for statistical matching
* Data: HBS 2019 and EU-SILC 2020
* Written by: Britta Rude (Poverty and Equity GP, World Bank)
* Last update: February 2023

* Important remarks: We follow the ECAPOV harmonization for income and energy  
*================================================================================



*==============================================================================*
* Step 1: Upload non-harmonized data 
*==============================================================================*

*Import data 
import excel "$data\Raw\hh_basic_${year}_HBS_BG.xlsx", clear firstrow

gen hhid=HA04
codebook HA04

global weight HA10

global samplevars HA06 HA07

*Add consumption aggregate
merge 1:1 hhid using "$data\consumptionagg.dta" //all match 
*Matched                             2,952
drop _merge

gen MA04 = hhid

*Prepare revelant household level variables 
********************************************************************************

***Individual level characteristics 

global hhid MA04

preserve

use "$data\Raw\hm_basic_2019_HBS_BG.dta", clear //all match
codebook MA04 //6,446 --> individual level

*pid_orig
gen str5 pid_orig = substr(MA05,2,1) 
replace pid_orig = "10" if MA05 == "10"
replace pid_orig = "11" if MA05 == "11" 
destring pid_orig , replace 
tab pid_orig

*female
destring MB02, replace 
gen female = (MB02==2)
tab female

*age
tab MB03
gen age = MB03  
replace age = "0"  if age == "Z0"
replace age = "1"  if age == "Z1"
replace age = "2"  if age == "Z2"
replace age = "3"  if age == "Z3"
replace age = "4"  if age == "Z4"
replace age = "5"  if age == "Z5"
replace age = "6"  if age == "Z6"
replace age = "7"  if age == "Z7"
replace age = "8"  if age == "Z8"
replace age = "9"  if age == "Z9"
destring age, replace 

*agecatn
gen agecatn = .
forval i=0(5)95 {
	replace agecatn = 1+`i'/5 if inrange(age,`i',`i'+4)
}
replace agecatn = 20 if age>=100
replace agecatn = 21 if age==.
la var	agecatn						"Age by 5-year intervals, categorical (numeric)"
lab define agecatn 1 "00-04 years"  2 "05-09 years"  3 "10-14 years"  4 "15-19 years"   ///
	5 "20-24 years"  6 "25-29 years"  7 "30-34 years"  8 "35-39 years"  ///
	9 "40-44 years"  10 "45-49 years"  11 "50-54 years"  12 "55-59 years"  ///
	13 "60-64 years"  14 "65-69 years"  15 "70-74 years"  16 "75-79 years"  ///
	17 "80-84 years"  18 "85-89 years"  19 "90-94 years"  20 "95+ years"  21 "Not stated",modify   
lab val agecatn agecatn
tab agecatn

*agecat
decode agecatn, gen(agecat)

*Child
gen child = (agecatn<4)
tab child

*Elderly
gen elderly = (agecatn>13)
tab elderly

*HH-head
destring MB05, replace 
gen head = (MB05 == 1)  
tab head

*Female household head
gen femalehead = (female>0 & head==1)
tab femalehead

*Roma 
*Does not exist

*Unemployed
codebook ME01_A //Missing "": 0/6,446

gen unemployed=0
replace unemployed=1 if ME01_A=="Z2"
tab unemployed

sum age if unemployed==1 //goes from 17 to 76

*Self-employed
codebook ME12 //string

gen selfemployed = 0
replace selfemployed=1 if ME12=="1" | ME12=="2"
tab selfemployed ME12

*Primary sector
gen primarysector=0
replace primarysector=1 if ME04=="A"
tab primarysector ME04

*Part-time
cap drop parttime
gen parttime = 0
replace parttime = 2 if ME02=="1"
tab parttime ME02

*Max educ primary
gen primaryeduc = 0
replace primaryeduc = 1 if MC01=="Z0" | MC01=="Z1"
tab MC01 primaryeduc

*Secondary 
gen secondaryeduc = 0
replace secondaryeduc = 1 if MC01=="Z2" | MC01=="Z3" | MC01=="Z4"
tab MC01 secondaryeduc

*Tertiary
gen tertiaryeduc = 0
replace tertiaryeduc = 1 if MC01=="Z5" | MC01=="Z6" | MC01=="Z7" | MC01=="Z8"
tab MC01 tertiaryeduc

*Currently attending education
gen attendingeduc = 0
replace attendingeduc = 1 if MC02_A=="1"
tab attendingeduc MC02_A

*Foreign citizenship
gen foreigncitizen = 0
replace foreigncitizen = 1 if MB011!="1"
tab MB011 foreigncitizen

*Pensioner
gen pensioner = (ME01_A=="Z3")
tab pensioner

*Adultequ
gen child_ad=0
replace child_ad=0.5 if child==1

gen women_ad=0
replace women_ad = 0.8 if female==1
replace women_ad = 0 if child==1
tab women_ad 


gen men_ad = 0
replace men_ad = 1 if female==0
replace men_ad = 0 if child==1
tab men

cap drop adultequ
egen adultequ = total(child_ad+women_ad+men_ad), by($hhid)

sort $hhid
list $hhid adultequ in 1/100


*Collapse to household level
********************************************************************************

global hhcharacteristics child pensioner elderly femalehead unemployed 
global memberinfo female selfemployed primarysector parttime primaryeduc secondaryeduc tertiaryeduc attendingeduc foreigncitizen

collapse (max) $hhcharacteristics (sum) $memberinfo nchild=child npensioner=pensioner nunemployed=unemployed (count) members=pid_orig (first) adultequ, by($hhid) //weight is not included in individual file  

foreach var in $hhcharacteristics{
	tab `var'
}

tab members
tab adultequ

label var child "Household with children (<15)"
label var pensioner "Household with pensioner"
label var elderly "Household with elderly (>64)"
label var femalehead "Female-headed household"
label var unemployed "Household with unemployed"
label var members "No. of household members"
label var adultequ "Adult equivalent"

label var nchild "No of children"
label var npensioner "No of pensioners"
label var nunemployed "No of unemployed"
label var female "No of female"
label var selfemployed "No of self-employed"
label var primarysector "No in primary sector"
label var parttime "No of part-time employed"
label var primaryeduc "No with primary educ."
label var secondaryeduc "No with secondary educ."
label var tertiaryeduc "No with tertiary educ."
label var attendingeduc "No attending educ."
label var foreigncitizen "No of foreign citizens"

*Save
tempfile hhcharacteristics
save `hhcharacteristics'

restore 

*Merge
merge 1:1 MA04 using `hhcharacteristics'
drop _merge


*Income category
********************************************************************************
codebook HH099

gen weight_rounded = round(${weight}, 1)

sum HH099 [w=$weight] //12758.19 (dfferent from official publication: 14,225)

*Income per adult equ. 
gen income_equ = HH099/adultequ
sum income_equ [w=$weight] //6306.273 (the official publication from 2019 mentions 6913)
label var income_equ "Net total income per adult equ."

*Income quintiles (based on adult equ.)
xtile income_equ_q = income_equ [w=$weight], nq(5)

tab income_equ_q
tab income_equ_q [iw=$weight]

sum income_equ if income_equ_q==1
sum income_equ if income_equ_q==5




*Prepare energy variables 
********************************************************************************

*Identify energ vars
global energyvars HE_04_5_1_0 HE_04_5_2_1 HE_04_5_2_2 HE_04_5_3_0 HE_04_5_4_1 HE_04_5_4_9 HE_04_5_5_0

foreach var in $energyvars{
	codebook `var'
	sum `var'
}

label var HE_04_5_1_0 "Electricity"
label var HE_04_5_2_1 "Natural gas and town gas"
label var HE_04_5_2_2 "Liquified hydrocarbons/butane/propane"
label var HE_04_5_3_0 "Liquid fuels"
label var HE_04_5_4_1 "Coal"
label var HE_04_5_4_9 "Other solid fuels"
label var HE_04_5_5_0 "Heat energy"

label var HE_04_5 "Energy expenditure"

sum HE_04_5 [w=${weight}] 



global energyvar HE_04_5
global welfarevar HH099 
global electricityspending HE_04_5_1_0

*Energy spending share

gen energyspendingshare = ${energyvar}/${welfarevar} 
sum energyspendingshare
sum energyspendingshare [iw=${weight}] 


***Save
gen weight = ${weight}

tempfile hbs2019
save `hbs2019'






*==============================================================================*
* Step 2: Upload imputed data 
*==============================================================================*


***Upload data
use "$data\Matching\imputed_eusilc.dta", clear

gen hhid_n=hhid
destring hhid_n, replace

preserve

use "${data}/SILC_2017_2020.dta", clear

tab ctry_n

tab year country

keep if code=="BGR"
keep if year==2020

tab year country 

*Save
tempfile eusilcbgr
save `eusilcbgr'

restore

merge 1:m hhid_n using `eusilcbgr'


		
***Income quintile		
		
global incomevar hx090 //hx090 is equ. dispo. income		
		
xtile income_equ_q = $incomevar [w=rb050], nq(5)

tab income_equ_q
tab income_equ_q [iw=rb050]

sum $incomevar if income_equ_q==1
sum $incomevar if income_equ_q==5

***Save

keep energyspendingshare_imp income_equ_q weight





*==============================================================================*
* Step 3: Append 
*==============================================================================*

append using `hbs2019'



*==============================================================================*
* Step 4: Figure 
*==============================================================================*


*Energy spending share by income quintiles

graph bar (mean) energyspendingshare_imp energyspendingshare [w=weight], over(income_equ_q) ///
legend(order(1 "Energy spend. share (imp.)" 2 "Energy spend. share")) 
graph export "$figures\eshare_comparison_quintiles.png", replace











